@@ -1,20 +1,28 @@
-( cd opt/kde/share/doc/HTML/et/kchart ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kchart ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kformula ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kformula ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kexi ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kexi ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kivio ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kivio ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/koffice ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/koffice ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/koshell ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/koshell ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kpresenter ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kpresenter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
-( cd opt/kde/share/doc/HTML/et/kspread ; rm -rf common )
-( cd opt/kde/share/doc/HTML/et/kspread ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/krita ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/krita ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kugar ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kugar ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/kword ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/kword ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/koffice ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/koffice ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/koshell ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/koshell ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kspread ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kspread ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/karbon ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/karbon ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kchart ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kchart ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kpresenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kpresenter ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kplato ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kplato ; ln -sf /opt/kde/share/doc/HTML/et/common common )
 ( cd opt/kde/share/doc/HTML/et/thesaurus ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/et/thesaurus ; ln -sf /opt/kde/share/doc/HTML/et/common common )
+( cd opt/kde/share/doc/HTML/et/kformula ; rm -rf common )
+( cd opt/kde/share/doc/HTML/et/kformula ; ln -sf /opt/kde/share/doc/HTML/et/common common )
